@@ -27,6 +27,8 @@ pub enum SubCommand {
     Scan(Scan),
     /// Run a background service that scans periodically
     Scheduler(Scheduler),
+    /// List threats that have been detected
+    Infections(Infections),
     /// Generate shell completions
     Completions(Completions),
 }
@@ -40,6 +42,16 @@ pub struct Scan {
 #[derive(StructOpt)]
 pub struct Scheduler {}
 
+#[derive(StructOpt)]
+pub struct Infections {
+    /// Interactively offer deletion for every file
+    #[structopt(short, long, group = "action")]
+    pub delete: bool,
+    /// Delete all files without further confirmation (DANGER!)
+    #[structopt(long, group = "action")]
+    pub delete_all: bool,
+}
+
 #[derive(Debug, Clone, StructOpt)]
 pub struct Completions {
     #[structopt(possible_values=&Shell::variants())]
